import 'package:dio/dio.dart';
import 'package:dio_cache_interceptor/dio_cache_interceptor.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter_rest_client/flutter_rest_client.dart';
import 'package:flutter_rest_client/src/dio/interceptors/error_interceptor.dart';
import 'package:flutter_rest_client/src/dio/interceptors/request_interceptor.dart';

import 'interceptors/pretty_logger.dart';



class DioBuilder {
  late Dio _dio;
  final IHttpConfig config;

  DioBuilder({required this.config});

  Dio build() {
    _dio = Dio();
    _dio
      ..options.connectTimeout = Duration(seconds: config.connectionTimeout)
      ..options.receiveTimeout = Duration(seconds:config.receiveTimeout )
      ..interceptors.add(ErrorInterceptor(_dio, config))
      ..interceptors.add(QueuedInterceptor())
      ..interceptors.add(RequestInterceptor(config).getInterceptor());

    if (config.customRequestInterceptor != null) {
      _dio..interceptors.add(config.customRequestInterceptor!);
    }

    if (kDebugMode) {
      if (config.dioLogger) {
        _dio..interceptors.add(PrettyLoggerInterceptor().prettyDioLogger);
      }
      // if (config.curlLogger) {
      //   _dio..interceptors.add(CurlLoggerDioInterceptor());
      // }
    }
    _dio.options.baseUrl = config.baseUrl;

    return _dio;
  }

  // Global options
  final options =  CacheOptions(
    store: MemCacheStore(),
    policy: CachePolicy.request,
    hitCacheOnErrorExcept: [401, 403],
    maxStale: const Duration(days: 2),
    priority: CachePriority.normal,
    cipher: null,
    keyBuilder: CacheOptions.defaultCacheKeyBuilder,
    allowPostMethod: false,
  );

}
